## Cross-reference for CELINE Unified Ontology Profile classes, object properties and data properties back to ToC

This section provides details for each class and property defined by CELINE Unified Ontology Profile.

### Classes

- Asset
- CO2 Emission Factor
- Energy Community
- Energy KPI
- Flexibility Event
- Forecast
- Meter
- Observation
- Prosumer
- Tariff
- Time Series

### Assetc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#Asset

has super-classes
  Device c
is in domain of
  has flexibility event op, has meter op, has observation op, is located in op
is in range of
  owns asset op

### CO2 Emission Factorc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#CO2Factor

has super-classes
  C O2 Emissions Factor c
is in range of
  has CO2 factor op

### Energy Communityc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#EnergyCommunity

has super-classes
  Community c
is in domain of
  evaluated by op, has CO2 factor op, has forecast op, has member op, has tariff op

### Energy KPIc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#EnergyKPI

has super-classes
  Energy Performance Indicator c, K P I Assessment c
is in range of
  evaluated by op

### Flexibility Eventc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#FlexibilityEvent

has super-classes
  Demand Response Event c
is in range of
  has flexibility event op

### Forecastc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#Forecast

has super-classes
  Forecast c
is in range of
  has forecast op

### Meterc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#Meter

has super-classes
  Energy Meter c
is in domain of
  has observation op, has time series op
is in range of
  has meter op

### Observationc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#Observation

has super-classes
  Observation c
is in range of
  has observation op

### Prosumerc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#Prosumer

has super-classes
  City object c
is in domain of
  has tariff op, owns asset op
is in range of
  has member op

### Tariffc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#Tariff

has super-classes
  Tariff c
is in range of
  has tariff op

### Time Seriesc back to ToC or Class ToC

IRI: https://celine-eu.github.io/ontologies/celine#TimeSeries

has super-classes
  Time Series List c
is in range of
  has time series op

### Object Properties

- evaluated by
- has CO2 factor
- has flexibility event
- has forecast
- has member
- has meter
- has observation
- has tariff
- has time series
- is located in
- measured consumption
- measured production
- owns asset

### evaluated byop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#evaluatedBy

has domain
  Energy Community c
has range
  Energy KPI c

### has CO2 factorop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#hasCO2Factor

has domain
  Energy Community c
has range
  CO2 Emission Factor c

### has flexibility eventop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#hasFlexibilityEvent

has domain
  Asset c
has range
  Flexibility Event c

### has forecastop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#hasForecast

has domain
  Energy Community c
has range
  Forecast c

### has memberop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#hasMember

has domain
  Energy Community c
has range
  Prosumer c

### has meterop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#hasMeter

has domain
  Asset c
has range
  Meter c

### has observationop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#hasObservation

has domain
  Asset c
  Meter c
has range
  Observation c

### has tariffop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#hasTariff

has domain
  Energy Community c
  Prosumer c
has range
  Tariff c

### has time seriesop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#hasTimeSeries

has domain
  Meter c
has range
  Time Series c

### is located inop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#isLocatedIn

has domain
  Asset c
has range
  Building Space c

### measured consumptionop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#measuredConsumption

has super-properties
  has Energy Consumption op

### measured productionop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#measuredProduction

has super-properties
  has Energy Production op

### owns assetop back to ToC or Object Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#ownsAsset

has domain
  Prosumer c
has range
  Asset c

### Data Properties

- point time
- point value
- timestamp
- value

### point timedp back to ToC or Data Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#pointTime

has super-properties
  date Time dp
has range
  date Time

### point valuedp back to ToC or Data Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#pointValue

has super-properties
  has Value dp
has range
  float

### timestampdp back to ToC or Data Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#timestamp

has range
  date Time

### valuedp back to ToC or Data Property ToC

IRI: https://celine-eu.github.io/ontologies/celine#value

has range
  float

## Legend back to ToC

c: Classes
op: Object Properties
dp: Data Properties